@@ -125,24 +125,6 @@ def handle_return(out_func, ret, system_stats, system_kwargs, user_kwargs):
     utils.handle_return_common(out_func, ret, system_stats, system_kwargs, user_kwargs)
 
 
-'''
-def check_serialized_size(args, factor=1.2):
-    big_data = 10 * 1024 * 1024 * 1024  # TODO: make this dynamic with cluster resources
-    cores = current_core_count()
-
-    # this is apprently not the current method used in ray, because ray can
-    # successfully pass ValueError() but pyarrow can't serialize it
-    serialized_size = len(pyarrow.serialize(args).to_buffer())
-
-    if serialized_size*cores*factor > big_data:
-        print('warning: in-flight data size seems to be too big', file=sys.stderr)
-    if serialized_size*cores*factor < big_data/3:
-        print('due to small in-flight data size, goosing factor by 2x', file=sys.stderr)
-        factor *= 2
-    return factor
-'''
-
-
 def progress_until_fewer(futures, cores, factor, out_func, system_stats, system_kwargs, user_kwargs, group_size):
     verbose = system_kwargs['verbose']
     vstats = system_kwargs['vstats']
@@ -211,21 +193,13 @@ def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=
     progress = system_kwargs['progress']
     cores = current_core_count()
 
-    # make a cut-down copy to minimize size of args
+    # make a cut-down copy to minimize size of args passed
     worker_system_kwargs = {}
-    for key in ('out_subdirs', 'chdir', 'name'):
+    for key in ('raise_in_wrapper', 'out_subdirs', 'chdir', 'name'):
         if key in system_kwargs:
             worker_system_kwargs[key] = system_kwargs[key]
 
-    # XXX temporarily diabled for Pandas
-    #factor = check_serialized_size((func, worker_system_kwargs, user_kwargs, psets[0]), factor=1.2)
-    factor = 2.4
-
-    # temporary: this works in ray map calls, but check serialize raises on it
-    # so we add it after checking the size
-    # remove this case once we fixe check_serialized_size to use the real ray serializer
-    if 'raise_in_wrapper' in system_kwargs:
-        worker_system_kwargs['raise_in_wrapper'] = system_kwargs['raise_in_wrapper']
+    factor = utils.pick_factor((func, worker_system_kwargs, user_kwargs, psets[0:0]))  # TODO: eventually will adjust group_size
 
     if group_size is None:
         # make this dynamic someday
