@@ -1,5 +1,7 @@
 #!/bin/sh
 
+set -e
+
 if [ ! -z "$COVERAGE" ]; then
     COVERAGE="--cov-report=xml --cov-append --cov-branch --cov paramsurvey -v -v"
 fi
@@ -15,16 +17,17 @@ echo $(hostname):$PORT $REDIS_PASSWORD > ~/.ray-test-72363726-details
 
 GIGABYTE=1000000000  # close enough
 
-ray start --head --port=$PORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE
+ray stop  # in case there's an a leftover ray
+ray start --head --port=$PORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE $RAY_START_EXTRAS
 
 # in order to find both the uninstalled paramsurvey and our test program,
 # which ray needs to pickle, the PYTHONPATH must be manipulated. See
 # ../../Makefile for clues.
 
-RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $1
-RAY_LOCAL_MODE=1 RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $PYTEST_STDERR_VISIBLE $1
+RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $RAY_PYTEST_EXTRAS $1
+RAY_LOCAL_MODE=1 RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $PYTEST_STDERR_VISIBLE $RAY_PYTEST_EXTRAS $1
 
-RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $1/test-generic_init_max_tasks_per_child.py
+RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $RAY_PYTEST_EXTRAS $1/test-generic_init_max_tasks_per_child.py
 # do not test max_tasks with local mode
 
 ray stop
