@@ -203,6 +203,14 @@ def test_worker_exception(capsys, paramsurvey_init):
     assert results.progress.failures == 1
     assert results.progress.exceptions == 1
 
+    psets2 = results.missing.to_psets()
+    assert len(psets2) == 1
+    m2 = next(paramsurvey.utils.DFIterDictsWrapper(psets2).iterdicts())
+    assert '_exception' not in m2
+    assert '_traceback' not in m2
+    assert 'raises' in m2
+    assert len(m2) == 1
+
     captured = readouterr_and_dump(capsys)
 
     # ray redirects stderr to stdout, while multiprocessing prints it in the worker
@@ -319,7 +327,7 @@ def test_subprocess_run():
     assert len(results) == len(psets)
     assert results.progress.total == len(psets)
     assert results.progress.finished == len(psets)
-    assert [r.ret.returncode == 0 for r in results.itertuples()], 'everyone exited 0'
+    assert [r.cli.returncode == 0 for r in results.itertuples()], 'everyone exited 0'
 
     psets = [{'run_args': '/this-command-does-not-exist', 'run_kwargs': {'check': True}}] * 10
     results = paramsurvey.map(subprocess_run_worker, psets)
@@ -330,7 +338,18 @@ def test_subprocess_run():
     for r in results.missing.iterdicts():
         assert 'FileNotFoundError' in r['_exception']
 
-    psets = [{'run_args': '/bin/false', 'run_kwargs': {'check': True}}] * 10
+    psets = [{'run_args': '/this-command-does-not-exist extra spaces'}] * 10
+    results = paramsurvey.map(subprocess_run_worker, psets)
+    assert len(results) == 0
+    assert results.progress.total == len(psets)
+    assert results.progress.finished == 0
+    assert results.progress.exceptions == len(psets)
+    for r in results.missing.iterdicts():
+        assert 'FileNotFoundError' in r['_exception']
+    # sadly, the worker stderr/out is not captured so we can't do this test:
+    #assert 'shell=True' in captured.err, 'saw shell=True warning from utils.subprocess_run_worker'
+
+    psets = [{'run_args': 'false', 'run_kwargs': {'check': True}}] * 10
     results = paramsurvey.map(subprocess_run_worker, psets)
     for r in results.missing.iterdicts():
         assert 'CalledProcessError' in r['_exception']
@@ -342,6 +361,6 @@ def test_subprocess_run():
     results = paramsurvey.map(subprocess_run_worker, psets, user_kwargs=user_kwargs)
     assert len(results) == len(psets)
     for r in results.itertuples():
-        assert isinstance(r.ret, subprocess.CompletedProcess)
-        assert r.ret.stdout.rstrip() == '/'
-        assert r.ret.returncode == 0
+        assert isinstance(r.cli, subprocess.CompletedProcess)
+        assert r.cli.stdout.rstrip() == '/'
+        assert r.cli.returncode == 0
